cdl_2crows

Function cdl_2crows 

pub fn cdl_2crows(
    open: &[f64],
    high: &[f64],
    low: &[f64],
    close: &[f64],
) -> Vec<i32>
Two crows: long white, then a black gapping up, then a black opening within the second body and closing within the first body. Always bearish.