cdl_3inside

Function cdl_3inside 

pub fn cdl_3inside(
    open: &[f64],
    high: &[f64],
    low: &[f64],
    close: &[f64],
) -> Vec<i32>
Three inside up/down: a long candle, a harami body engulfed by it, then a confirming candle of the opposite color to the first.