cdl_ladderbottom

Function cdl_ladderbottom 

pub fn cdl_ladderbottom(
    open: &[f64],
    high: &[f64],
    low: &[f64],
    close: &[f64],
) -> Vec<i32>
Ladder bottom: three declining black candles, a black candle with an upper shadow, then a white candle breaking out.