cdl_thrusting

Function cdl_thrusting 

pub fn cdl_thrusting(
    open: &[f64],
    high: &[f64],
    low: &[f64],
    close: &[f64],
) -> Vec<i32>
Thrusting: a black candle followed by a white candle closing into, but under the midpoint of, the prior body.